<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>AppItemMenu</name>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Pin to Top</source>
        <translation>移到顶部</translation>
    </message>
    <message>
        <source>Move to Top</source>
        <translation>移至顶部</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>从收藏中移除</translation>
    </message>
    <message>
        <source>Add to favorites</source>
        <translation>添加到收藏</translation>
    </message>
    <message>
        <source>Remove from desktop</source>
        <translation>从桌面上移除</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>发送到桌面</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>从任务栏上移除</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>发送到任务栏</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>取消开机自动启动</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>开机自动启动</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation>使用代理</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>禁用屏幕缩放</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>卸载</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <source>Power</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>Full-screen Mode</source>
        <translation>全屏模式</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <source>Install</source>
        <translation>安装</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <source>Frequently Used</source>
        <translation>我的常用</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Window Mode</source>
        <translation>窗口模式</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Internet</source>
        <translation>网络应用</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>社交沟通</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音乐欣赏</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>视频播放</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>图形图像</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>游戏娱乐</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>办公学习</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>阅读翻译</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>编程开发</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系统管理</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>其他应用</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>您确定要卸载“%1”吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>确 定</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <source>Recently Installed</source>
        <translation>最近安装</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <source>All Apps</source>
        <translation>所有应用</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>无搜索结果</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <source>Free sorting</source>
        <translation>自由排序</translation>
    </message>
    <message>
        <source>Sort by category</source>
        <translation>按分类</translation>
    </message>
    <message>
        <source>Sort by name</source>
        <translation>按名称</translation>
    </message>
    <message>
        <source>Sorting Mode</source>
        <translation>排序模式</translation>
    </message>
    <message>
        <source>Computer</source>
        <translation>计算机</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>图片</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文档</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <source>Control Center</source>
        <translation>控制中心</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <source>Internet</source>
        <translation>网络应用</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>社交沟通</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音乐欣赏</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>视频播放</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>图形图像</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>游戏娱乐</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>办公学习</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>阅读翻译</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>编程开发</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系统管理</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>其他应用</translation>
    </message>
    <message>
        <source>launchpad</source>
        <translation>启动器</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>您确定要卸载“%1”吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>确 定</translation>
    </message>
</context>
</TS>